@@ -4,10 +4,11 @@ use std::env;
 
 
 fn main() -> Result<(), Error> {
+    let args: Vec<String> = env::args().collect();
     let status = if cfg!(unix) {
-        Command::new("./mach").args(env::args()).status()?
+        Command::new("./mach").args(&args[2..]).status()?
     } else {
-        Command::new("mach.bat").args(env::args()).status()?
+        Command::new("mach.bat").args(&args[2..]).status()?
     };
     assert!(status.success());
     Ok(())
